@@ -12,18 +12,17 @@ module Hledger.UI.AccountsScreen
 where
 
 import Brick
-import Brick.Widgets.List
+import Brick.Widgets.List hiding (reverse)
 import Brick.Widgets.Edit
-import Brick.Widgets.Border (borderAttr)
 import Control.Monad
 import Control.Monad.IO.Class (liftIO)
 import Data.List
 import Data.Maybe
 #if !(MIN_VERSION_base(4,11,0))
-import Data.Monoid
+import Data.Monoid ((<>))
 #endif
 import qualified Data.Text as T
-import Data.Time.Calendar (Day)
+import Data.Time.Calendar (Day, addDays)
 import qualified Data.Vector as V
 import Graphics.Vty (Event(..),Key(..),Modifier(..))
 import Lens.Micro.Platform
@@ -80,13 +79,19 @@ asInit d reset ui@UIState{
                         as = map asItemAccountName displayitems
 
     uopts' = uopts{cliopts_=copts{reportopts_=ropts'}}
-    ropts' = ropts{accountlistmode_=if flat_ ropts then ALFlat else ALTree}
+    ropts' = ropts{accountlistmode_=if tree_ ropts then ALTree else ALFlat}
 
-    q = queryFromOpts d ropts
+    -- Add a date:-tomorrow to the query to exclude future txns, by default.
+    -- XXX this necessitates special handling in multiBalanceReport, at least
+    pfq | presentorfuture_ uopts == PFFuture = Any
+        | otherwise                          = Date $ DateSpan Nothing (Just $ addDays 1 d)
+    q = And [queryFromOpts d ropts, pfq]
+        
 
     -- run the report
     (items,_total) = report ropts' q j
       where
+                 -- XXX in historical mode, --forecast throws off the starting balances
         report | balancetype_ ropts == HistoricalBalance = balanceReportFromMultiBalanceReport
                | otherwise                               = balanceReport
                     -- still using the old balanceReport for change reports as it
@@ -97,7 +102,7 @@ asInit d reset ui@UIState{
     displayitem (fullacct, shortacct, indent, bal) =
       AccountsScreenItem{asItemIndentLevel        = indent
                         ,asItemAccountName        = fullacct
-                        ,asItemDisplayAccountName = replaceHiddenAccountsNameWith "All" $ if flat_ ropts' then fullacct else shortacct
+                        ,asItemDisplayAccountName = replaceHiddenAccountsNameWith "All" $ if tree_ ropts' then shortacct else fullacct 
                         ,asItemRenderedAmounts    = map showAmountWithoutPrice amts -- like showMixedAmountOneLineWithoutPrice
                         }
       where
@@ -116,7 +121,7 @@ asInit d reset ui@UIState{
 asInit _ _ _ = error "init function called with wrong screen type, should not happen"
 
 asDraw :: UIState -> [Widget Name]
-asDraw UIState{aopts=UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
+asDraw UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
                            ,ajournal=j
                            ,aScreen=s@AccountsScreen{}
                            ,aMode=mode
@@ -167,8 +172,8 @@ asDraw UIState{aopts=UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
         ishistorical = balancetype_ ropts == HistoricalBalance
 
         toplabel =
-              files
-          -- <+> withAttr (borderAttr <> "query") (str (if flat_ ropts then " flat" else ""))
+              withAttr ("border" <> "filename") files
+          -- <+> withAttr ("border" <> "query") (str (if flat_ ropts then " flat" else ""))
           <+> nonzero
           <+> str (if ishistorical then " accounts" else " account changes")
           -- <+> str (if ishistorical then " balances" else " changes")
@@ -182,12 +187,12 @@ asDraw UIState{aopts=UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
           <+> total
           <+> str ")"
           <+> (if ignore_assertions_ $ inputopts_ copts
-               then withAttr (borderAttr <> "query") (str " ignoring balance assertions")
+               then withAttr ("border" <> "query") (str " ignoring balance assertions")
                else str "")
           where
             files = case journalFilePaths j of
                            [] -> str ""
-                           f:_ -> withAttr ("border" <> "bold") $ str $ takeFileName f
+                           f:_ -> str $ takeFileName f
                            -- [f,_:[]] -> (withAttr ("border" <> "bold") $ str $ takeFileName f) <+> str " (& 1 included file)"
                            -- f:fs  -> (withAttr ("border" <> "bold") $ str $ takeFileName f) <+> str (" (& " ++ show (length fs) ++ " included files)")
             querystr = query_ ropts
@@ -198,9 +203,9 @@ asDraw UIState{aopts=UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
                   ,if real_ ropts then ["real"] else []
                   ] of
                 [] -> str ""
-                fs -> str " from " <+> withAttr (borderAttr <> "query") (str $ intercalate ", " fs) <+> str " txns"
+                fs -> str " from " <+> withAttr ("border" <> "query") (str $ intercalate ", " fs) <+> str " txns"
             nonzero | empty_ ropts = str ""
-                    | otherwise    = withAttr (borderAttr <> "query") (str " nonzero")
+                    | otherwise    = withAttr ("border" <> "query") (str " nonzero")
             cur = str (case _asList s ^. listSelectedL of
                         Nothing -> "-"
                         Just i -> show (i + 1))
@@ -211,19 +216,13 @@ asDraw UIState{aopts=UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
                         Minibuffer ed -> minibuffer ed
                         _             -> quickhelp
           where
-            selectedstr = withAttr (borderAttr <> "query") . str
             quickhelp = borderKeysStr' [
                ("?", str "help")
-              ,("right", str "register")
-              ,("H"
-               ,if ishistorical
-                then selectedstr "historical" <+> str "/period"
-                else str "historical/" <+> selectedstr "period")
-              ,("F"
-               ,if flat_ ropts
-                then str "tree/" <+> selectedstr "flat"
-                else selectedstr "tree" <+> str "/flat")
+--              ,("RIGHT", str "register")
               ,("-+", str "depth")
+              ,("T", renderToggle (tree_ ropts) "flat" "tree")
+              ,("H", renderToggle (not ishistorical) "end-bals" "changes")
+              ,("F", renderToggle (presentorfuture_ uopts == PFFuture) "present" "future") 
               --,("/", "filter")
               --,("DEL", "unfilter")
               --,("ESC", "cancel/top")
@@ -332,12 +331,13 @@ asHandle ui0@UIState{
 
         -- display mode/query toggles
         VtyEvent (EvKey (KChar 'H') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleHistorical ui
-        VtyEvent (EvKey (KChar 'F') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleFlat ui
+        VtyEvent (EvKey (KChar 'T') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleTree ui
         VtyEvent (EvKey (KChar 'Z') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleEmpty ui
         VtyEvent (EvKey (KChar 'R') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleReal ui
         VtyEvent (EvKey (KChar 'U') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleUnmarked ui
         VtyEvent (EvKey (KChar 'P') []) -> asCenterAndContinue $ regenerateScreens j d $ togglePending ui
         VtyEvent (EvKey (KChar 'C') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleCleared ui
+        VtyEvent (EvKey (KChar 'F') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleFuture ui
 
         VtyEvent (EvKey (KDown)     [MShift]) -> continue $ regenerateScreens j d $ shrinkReportPeriod d ui
         VtyEvent (EvKey (KUp)       [MShift]) -> continue $ regenerateScreens j d $ growReportPeriod d ui
