@@ -12,7 +12,7 @@ module Hledger.UI.ErrorScreen
 where
 
 import Brick
--- import Brick.Widgets.Border (borderAttr)
+-- import Brick.Widgets.Border ("border")
 import Control.Monad
 import Control.Monad.IO.Class (liftIO)
 #if !(MIN_VERSION_base(4,11,0))
@@ -57,7 +57,7 @@ esDraw UIState{aopts=UIOpts{cliopts_=copts@CliOpts{}}
       where
         toplabel =
               withAttr ("border" <> "bold") (str "Oops. Please fix this problem then press g to reload")
-              -- <+> (if ignore_assertions_ copts then withAttr (borderAttr <> "query") (str " ignoring") else str " not ignoring")
+              -- <+> (if ignore_assertions_ copts then withAttr ("border" <> "query") (str " ignoring") else str " not ignoring")
 
         bottomlabel = case mode of
                         -- Minibuffer ed -> minibuffer ed
@@ -110,15 +110,27 @@ esHandle _ _ = error "event handler called with wrong screen type, should not ha
 
 -- | Parse the file name, line and column number from a hledger parse error message, if possible.
 -- Temporary, we should keep the original parse error location. XXX
+-- Keep in sync with 'Hledger.Data.Transaction.showGenericSourcePos'
 hledgerparseerrorpositionp :: ParsecT Void String t (String, Int, Int)
 hledgerparseerrorpositionp = do
-  anyChar `manyTill` char '"'
-  f <- anyChar `manyTill` (oneOf ['"','\n'])
-  string " (line "
-  l <- read <$> some digitChar
-  string ", column "
-  c <- read <$> some digitChar
-  return (f, l, c)
+  anySingle `manyTill` char '"'
+  f <- anySingle `manyTill` (oneOf ['"','\n'])
+  choice [
+      do
+          string " (line "
+          l <- read <$> some digitChar
+          string ", column "
+          c <- read <$> some digitChar
+          return (f, l, c),
+      do
+          string " (lines "
+          l <- read <$> some digitChar
+          char '-'
+          some digitChar
+          char ')'
+          return (f, l, 1)
+      ]
+
 
 -- Unconditionally reload the journal, regenerating the current screen
 -- and all previous screens in the history.
