@@ -1,11 +1,14 @@
 {-# LANGUAGE CPP #-}
+{-# LANGUAGE DeriveDataTypeable #-}
 {-|
 
 -}
 
 module Hledger.UI.UIOptions
 where
+import Data.Data (Data)
 import Data.Default
+import Data.Typeable (Typeable)
 import Data.List (intercalate)
 import System.Environment
 
@@ -33,19 +36,13 @@ uiflags = [
   --   "show balance change accumulated across periods (in multicolumn reports)"
   -- ,flagNone ["historical","H"] (\opts -> setboolopt "historical" opts)
   --   "show historical ending balance in each period (includes postings before report start date)\n "
-  ,flagNone ["flat"] (\opts -> setboolopt "flat" opts) "show full account names, unindented"
+  ,flagNone ["flat","F"] (\opts -> setboolopt "flat" opts) "show accounts as a list (default)"
+  ,flagNone ["tree","T"] (\opts -> setboolopt "tree" opts) "show accounts as a tree"
+--  ,flagNone ["present"] (\opts -> setboolopt "present" opts) "exclude transactions dated later than today (default)"
+  ,flagNone ["future"] (\opts -> setboolopt "future" opts) "show transactions dated later than today (normally hidden)"
   -- ,flagReq ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "with --flat, omit this many leading account name components"
   -- ,flagReq  ["format"] (\s opts -> Right $ setopt "format" s opts) "FORMATSTR" "use this custom line format"
   -- ,flagNone ["no-elide"] (\opts -> setboolopt "no-elide" opts) "don't compress empty parent accounts on one line"
-  ,flagReq  ["status-toggles"] (\s opts -> Right $ setopt "status-toggles" s opts) "N"
-    (intercalate "\n"
-      ["choose how status toggles work:"
-      ," 1 UPC toggles X/all"
-      ," 2 UPC cycles X/not-X/all"
-      ," 3 UPC toggles each X"
---      ," 4 upc sets X, UPC sets not-X"
---      ," 5 upc toggles X, UPC toggles not-X"
-      ])
  ]
 
 --uimode :: Mode [([Char], [Char])]
@@ -66,6 +63,7 @@ uimode =  (mode "hledger-ui" [("command","ui")]
 data UIOpts = UIOpts {
      watch_   :: Bool
     ,change_  :: Bool
+    ,presentorfuture_  :: PresentOrFutureOpt
     ,cliopts_ :: CliOpts
  } deriving (Show)
 
@@ -73,6 +71,7 @@ defuiopts = UIOpts
     def
     def
     def
+    def
 
 -- instance Default CliOpts where def = defcliopts
 
@@ -82,9 +81,22 @@ rawOptsToUIOpts rawopts = checkUIOpts <$> do
   return defuiopts {
               watch_   = boolopt "watch" rawopts
              ,change_  = boolopt "change" rawopts
+             ,presentorfuture_ = presentorfutureopt rawopts
              ,cliopts_ = cliopts
              }
 
+-- | Should transactions dated later than today be included ? 
+-- Like flat/tree mode, there are three states, and the meaning of default can vary by command.
+data PresentOrFutureOpt = PFDefault | PFPresent | PFFuture deriving (Eq, Show, Data, Typeable)
+instance Default PresentOrFutureOpt where def = PFDefault
+
+presentorfutureopt :: RawOpts -> PresentOrFutureOpt
+presentorfutureopt rawopts =
+  case reverse $ filter (`elem` ["present","future"]) $ map fst rawopts of
+    ("present":_) -> PFPresent
+    ("future":_)  -> PFFuture
+    _             -> PFDefault
+
 checkUIOpts :: UIOpts -> UIOpts
 checkUIOpts opts =
   either usageError (const opts) $ do
